==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/AccessLoggingBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AccessLoggingBuilder extends io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluentImpl<io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.AccessLogging,io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder>{
  public AccessLoggingBuilder() {
    this(false);
  }
  public AccessLoggingBuilder(java.lang.Boolean validationEnabled) {
    this(new AccessLogging(), validationEnabled);
  }
  public AccessLoggingBuilder(io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent<?> fluent) {
    this(fluent, false);
  }
  public AccessLoggingBuilder(io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AccessLogging(), validationEnabled);
  }
  public AccessLoggingBuilder(io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AccessLogging instance) {
    this(fluent, instance, false);
  }
  public AccessLoggingBuilder(io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AccessLogging instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDestination(instance.getDestination()); 
    fluent.withHttpCaptureCookies(instance.getHttpCaptureCookies()); 
    fluent.withHttpCaptureHeaders(instance.getHttpCaptureHeaders()); 
    fluent.withHttpLogFormat(instance.getHttpLogFormat()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AccessLoggingBuilder(io.fabric8.openshift.api.model.operator.v1.AccessLogging instance) {
    this(instance,false);
  }
  public AccessLoggingBuilder(io.fabric8.openshift.api.model.operator.v1.AccessLogging instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDestination(instance.getDestination()); 
    this.withHttpCaptureCookies(instance.getHttpCaptureCookies()); 
    this.withHttpCaptureHeaders(instance.getHttpCaptureHeaders()); 
    this.withHttpLogFormat(instance.getHttpLogFormat()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.AccessLogging build() {
    AccessLogging buildable = new AccessLogging(fluent.getDestination(),fluent.getHttpCaptureCookies(),fluent.getHttpCaptureHeaders(),fluent.getHttpLogFormat());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AccessLoggingBuilder that = (AccessLoggingBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/AccessLoggingBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AccessLoggingBuilder extends io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluentImpl<io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.AccessLogging,io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder>{
  public AccessLoggingBuilder() {
    this(false);
  }
  public AccessLoggingBuilder(java.lang.Boolean validationEnabled) {
    this(new AccessLogging(), validationEnabled);
  }
  public AccessLoggingBuilder(io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent<?> fluent) {
    this(fluent, false);
  }
  public AccessLoggingBuilder(io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AccessLogging(), validationEnabled);
  }
  public AccessLoggingBuilder(io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AccessLogging instance) {
    this(fluent, instance, false);
  }
  public AccessLoggingBuilder(io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.AccessLogging instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDestination(instance.getDestination()); 
    fluent.withHttpCaptureCookies(instance.getHttpCaptureCookies()); 
    fluent.withHttpCaptureHeaders(instance.getHttpCaptureHeaders()); 
    fluent.withHttpLogFormat(instance.getHttpLogFormat()); 
    fluent.withLogEmptyRequests(instance.getLogEmptyRequests()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AccessLoggingBuilder(io.fabric8.openshift.api.model.operator.v1.AccessLogging instance) {
    this(instance,false);
  }
  public AccessLoggingBuilder(io.fabric8.openshift.api.model.operator.v1.AccessLogging instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDestination(instance.getDestination()); 
    this.withHttpCaptureCookies(instance.getHttpCaptureCookies()); 
    this.withHttpCaptureHeaders(instance.getHttpCaptureHeaders()); 
    this.withHttpLogFormat(instance.getHttpLogFormat()); 
    this.withLogEmptyRequests(instance.getLogEmptyRequests()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.AccessLogging build() {
    AccessLogging buildable = new AccessLogging(fluent.getDestination(),fluent.getHttpCaptureCookies(),fluent.getHttpCaptureHeaders(),fluent.getHttpLogFormat(),fluent.getLogEmptyRequests());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AccessLoggingBuilder that = (AccessLoggingBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
